@@ -21,14 +21,13 @@
 #ifndef BUGZILLALIB__H
 #define BUGZILLALIB__H
 
-#include <kxmlrpcclient/client.h>
-
 #include <QtCore/QObject>
 #include <QtCore/QMap>
 #include <QtCore/QStringList>
-
 #include <QtXml/QDomDocument>
 
+#include <kxmlrpcclient/client.h>
+
 namespace KIO { class Job; }
 class KJob;
 class QString;
@@ -284,18 +283,88 @@ private:
     QByteArray  m_data;
 };
 
+class Component
+{
+public:
+    Component(const QString& name, bool active): m_name(name), m_active(active) {}
+
+    QString name() const { return m_name; }
+    bool active() const { return m_active; }
+
+private:
+    QString m_name;
+    bool m_active;
+};
+
+class Version
+{
+public:
+
+    Version(const QString& name, bool active): m_name(name), m_active(active) {}
+
+    QString name() const { return m_name; }
+    bool active() const { return m_active; }
+
+private:
+    QString m_name;
+    bool m_active;
+};
+
+
+class Product
+{
+public:
+
+    Product(const QString& name, bool active): m_name(name), m_active(active) {}
+
+    bool isActive() const { return m_active; }
+
+    void addComponent(const Component& component) {
+        m_allComponents.append(component.name());
+    }
+
+    void addVersion(const Version& version) {
+        m_allVersions.append(version.name());
+
+        if (version.active()) {
+            m_activeVersions.append(version.name());
+        } else {
+            m_inactiveVersions.append(version.name());
+        }
+    }
+
+    QStringList components() const { return m_allComponents; }
+
+    QStringList allVersions() const { return m_allVersions; }
+    QStringList activeVersions() const { return m_activeVersions; }
+    QStringList inactiveVersions() const { return m_inactiveVersions; }
+
+private:
+
+    QString m_name;
+    bool m_active;
+
+    QStringList m_allComponents;
+
+    QStringList m_allVersions;
+    QStringList m_activeVersions;
+    QStringList m_inactiveVersions;
+
+};
+
 class BugzillaManager : public QObject
 {
     Q_OBJECT
 
 public:
-    explicit BugzillaManager(QObject *parent = 0);
+    // Note: it expect the bugTrackerUrl parameter to contain the trailing slash.
+    // so it should be "https://bugs.kde.org/", not "https://bugs.kde.org"
+    explicit BugzillaManager(const QString &bugTrackerUrl, QObject *parent = 0);
 
     /* Login methods */
-    void tryLogin();
+    void tryLogin(const QString&, const QString&);
     bool getLogged() const;
 
-    void setLoginData(const QString &, const QString &);
     QString getUsername() const;
 
     /* Bugzilla Action methods */
@@ -311,20 +380,18 @@ public:
 
     void addMeToCC(int bugId);
 
-    void checkVersionsForProduct(const QString &);
+    void fetchProductInfo(const QString &);
 
     /* Misc methods */
     QString urlForBug(int bug_number) const;
 
-    void setCustomBugtrackerUrl(const QString &);
-
     void stopCurrentSearch();
 
 private Q_SLOTS:
     /* Slots to handle KJob::finished */
     void fetchBugJobFinished(KJob*);
     void searchBugsJobFinished(KJob*);
-    void checkVersionJobFinished(KJob*);
+    void fetchProductInfoFinished(const QVariantMap&);
 
     void callMessage(const QList<QVariant> & result, const QVariant & id);
     void callFault(int errorCode, const QString & errorString, const QVariant &id);
@@ -337,7 +404,7 @@ Q_SIGNALS:
     void reportSent(int);
     void attachToReportSent(int);
     void addMeToCCFinished(int);
-    void checkVersionsForProductFinished(const QStringList);
+    void productInfoFetched(Product);
 
     /* Bugzilla actions had errors */
     void loginError(const QString & errorMsg, const QString & extendedErrorMsg = QString());
@@ -347,17 +414,15 @@ Q_SIGNALS:
     void sendReportErrorInvalidValues(); //To use default values
     void attachToReportError(const QString & errorMsg, const QString & extendedErrorMsg = QString());
     void addMeToCCError(const QString & errorMsg, const QString & extendedErrorMsg = QString());
-    void checkVersionsForProductError();
+    void productInfoError();
 
 private:
+    QString     m_bugTrackerUrl;
     QString     m_username;
-    QString     m_password;
     bool        m_logged;
 
     KIO::Job *  m_searchJob;
     KXmlRpc::Client *m_xmlRpcClient;
-
-    QString     m_bugTrackerUrl;
 };
 
 #endif
